@@ -1,13 +1,39 @@
-//---------------------------------------------------------------------------
-//
-// amorwidget.cpp
-//
-// Copyright (c) 1999 Martin R. Jones <mjones@kde.org>
-//
+/* amorwidget.cpp
+**
+** Copyright (c) 1999 Martin R. Jones <mjones@kde.org>
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
 
 #include "amorwidget.h"
 #include "amorwidget.moc"
-#include <qbitmap.h>
+
+#include <QtGui/QBitmap>
+#include <QtGui/QPainter>
+#include <QtGui/QPixmap>
+#include <QtGui/QMouseEvent>
+#include <QtGui/QX11Info>
+
 #include <X11/Xlib.h>
 #include <X11/extensions/shape.h>
 
@@ -16,10 +42,10 @@
 // Constructor
 //
 AmorWidget::AmorWidget()
-	: QWidget(0, 0, WStyle_Customize | WStyle_NoBorder | WX11BypassWM ),
+	: QWidget(0, Qt::WindowTitleHint | Qt::X11BypassWindowManagerHint),
       mPixmap(0)
 {
-    setBackgroundMode( NoBackground );
+    setAttribute(Qt::WA_NoSystemBackground, true);
     dragging = false;
 }
 
@@ -37,15 +63,18 @@ AmorWidget::~AmorWidget()
 //
 void AmorWidget::setPixmap(const QPixmap *pixmap)
 {
-    if (pixmap)
+    mPixmap = pixmap;
+
+    if (mPixmap)
     {
-        mPixmap = pixmap;
-        if (mPixmap->mask())
+        if (!mPixmap->mask().isNull())
         {
-            XShapeCombineMask( x11Display(), winId(), ShapeBounding, 0, 0,
-                                mPixmap->mask()->handle(), ShapeSet );
-            repaint(false);
+            XShapeCombineMask( QX11Info::display(), winId(), ShapeBounding, 0, 0,
+                                mPixmap->mask().handle(), ShapeSet );
+            repaint();
         }
+
+	update();
     }
 }
 
@@ -56,7 +85,10 @@ void AmorWidget::setPixmap(const QPixmap *pixmap)
 void AmorWidget::paintEvent(QPaintEvent *)
 {
     if (mPixmap)
-        bitBlt( this, 0, 0, mPixmap );
+    {
+        QPainter p(this);
+        p.drawPixmap( 0, 0, *mPixmap );
+    }
 }
 
 //---------------------------------------------------------------------------
@@ -74,7 +106,7 @@ void AmorWidget::mousePressEvent(QMouseEvent *me)
 //
 void AmorWidget::mouseMoveEvent(QMouseEvent *me)
 {
-    if ( me->state() == LeftButton ) {
+    if ( me->buttons() & Qt::LeftButton ) {
 	if ( !dragging && (clickPos-me->globalPos()).manhattanLength() > 3 )
 	    dragging = true;
 	if ( dragging ) {
@@ -92,8 +124,8 @@ void AmorWidget::mouseReleaseEvent(QMouseEvent *me)
 {
     if ( dragging )
 	emit dragged( me->globalPos() - clickPos, true );
-    else if ( me->state() == RightButton )
-	emit mouseClicked(clickPos);
+    else if ( me->button() == Qt::RightButton )
+	emit mouseClicked(me->globalPos());
 
     clickPos = QPoint();
     dragging = false;
